---
name: 📕 Document request
about: Suggest add docs for project
labels: documentation
---

<!--
Welcome! Thanks for thinking of a way to improve our project. If this solves a problem for you, then it probably solves that problem for lots of people! So the whole community will benefit from this request.

Before creating a new feature request please search the issues for relevant feature requests.
-->

### Problem

<!-- Provide a clear and concise description of what problem this feature will solve. For example:

* I'm always frustrated when [...] because [...]
* I would like it if [...] happened when I [...] because [...]
-->

### Model for documentation

<!-- Provide a clear and concise description of the model for documentation. For example:

* Add a tutorial on [...]
* Need to clearify [...]
* How to use [...]
-->

### Additional context

<!-- Add any other context or screenshots about the feature request here. You can also include links to examples of other programs that have something similar to your request. For example:

* Another project [...] solved this by [...]
* I found [...] already in [...] but [...]
-->
